==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeExecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReadinessProbeExecFluent<A extends ReadinessProbeExecFluent<A>> extends BaseFluent<A>{
  public ReadinessProbeExecFluent() {
  }
  public ReadinessProbeExecFluent(ReadinessProbeExec instance) {
    instance = (instance != null ? instance : new ReadinessProbeExec());

    if (instance != null) {
      this.withExec(instance.getExec());
      this.withExec(instance.getExec());
    }
  }
  private ExecHealthCheckConfigBuilder exec;
  public ExecHealthCheckConfig buildExec() {
    return this.exec!=null ?this.exec.build():null;
  }
  public A withExec(ExecHealthCheckConfig exec) {
    _visitables.get("exec").remove(this.exec);
    if (exec!=null){ this.exec= new ExecHealthCheckConfigBuilder(exec); _visitables.get("exec").add(this.exec);} else { this.exec = null; _visitables.get("exec").remove(this.exec); } return (A) this;
  }
  public boolean hasExec() {
    return this.exec != null;
  }
  public ExecNested<A> withNewExec() {
    return new ExecNested(null);
  }
  public ExecNested<A> withNewExecLike(ExecHealthCheckConfig item) {
    return new ExecNested(item);
  }
  public ExecNested<A> editExec() {
    return withNewExecLike(java.util.Optional.ofNullable(buildExec()).orElse(null));
  }
  public ExecNested<A> editOrNewExec() {
    return withNewExecLike(java.util.Optional.ofNullable(buildExec()).orElse(new ExecHealthCheckConfigBuilder().build()));
  }
  public ExecNested<A> editOrNewExecLike(ExecHealthCheckConfig item) {
    return withNewExecLike(java.util.Optional.ofNullable(buildExec()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReadinessProbeExecFluent that = (ReadinessProbeExecFluent) o;
    if (!java.util.Objects.equals(exec, that.exec)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(exec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exec != null) { sb.append("exec:"); sb.append(exec); }
    sb.append("}");
    return sb.toString();
  }
  public class ExecNested<N> extends ExecHealthCheckConfigFluent<ExecNested<N>> implements Nested<N>{
    ExecNested(ExecHealthCheckConfig item) {
      this.builder = new ExecHealthCheckConfigBuilder(this, item);
    }
    ExecHealthCheckConfigBuilder builder;
    public N and() {
      return (N) ReadinessProbeExecFluent.this.withExec(builder.build());
    }
    public N endExec() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeExecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ReadinessProbeExecFluent<A extends ReadinessProbeExecFluent<A>> extends BaseFluent<A>{
  public ReadinessProbeExecFluent() {
  }
  
  public ReadinessProbeExecFluent(ReadinessProbeExec instance) {
    this.copyInstance(instance);
  }
  private ExecHealthCheckConfigBuilder exec;
  
  protected void copyInstance(ReadinessProbeExec instance) {
    instance = (instance != null ? instance : new ReadinessProbeExec());
  
    if (instance != null) {
        this.withExec(instance.getExec());
        this.withExec(instance.getExec());
      }
  }
  
  public ExecHealthCheckConfig buildExec() {
    return this.exec!=null ?this.exec.build():null;
  }
  
  public A withExec(ExecHealthCheckConfig exec) {
    _visitables.get("exec").remove(this.exec);
    if (exec!=null){ this.exec= new ExecHealthCheckConfigBuilder(exec); _visitables.get("exec").add(this.exec);} else { this.exec = null; _visitables.get("exec").remove(this.exec); } return (A) this;
  }
  
  public boolean hasExec() {
    return this.exec != null;
  }
  
  public ExecNested<A> withNewExec() {
    return new ExecNested(null);
  }
  
  public ExecNested<A> withNewExecLike(ExecHealthCheckConfig item) {
    return new ExecNested(item);
  }
  
  public ExecNested<A> editExec() {
    return withNewExecLike(java.util.Optional.ofNullable(buildExec()).orElse(null));
  }
  
  public ExecNested<A> editOrNewExec() {
    return withNewExecLike(java.util.Optional.ofNullable(buildExec()).orElse(new ExecHealthCheckConfigBuilder().build()));
  }
  
  public ExecNested<A> editOrNewExecLike(ExecHealthCheckConfig item) {
    return withNewExecLike(java.util.Optional.ofNullable(buildExec()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReadinessProbeExecFluent that = (ReadinessProbeExecFluent) o;
    if (!java.util.Objects.equals(exec, that.exec)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(exec,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exec != null) { sb.append("exec:"); sb.append(exec); }
    sb.append("}");
    return sb.toString();
  }
  public class ExecNested<N> extends ExecHealthCheckConfigFluent<ExecNested<N>> implements Nested<N>{
    ExecNested(ExecHealthCheckConfig item) {
      this.builder = new ExecHealthCheckConfigBuilder(this, item);
    }
    ExecHealthCheckConfigBuilder builder;
    
    public N and() {
      return (N) ReadinessProbeExecFluent.this.withExec(builder.build());
    }
    
    public N endExec() {
      return and();
    }
    
  
  }

}
